# beta priors
x<-seq(0,1,length=1000)
par(mfrow=c(1,2))
plot(x,dbeta(x,1,1),type="l",xlab=expression(pi),ylab="density",main=expression(alpha ~ "= 1, " ~ beta ~ "= 1"))
plot(x,dbeta(x,3,3),type="l",xlab=expression(pi),ylab="density",main=expression(alpha ~ "= 3, " ~ beta ~ "= 3"))

# likelihood
par(mfrow=c(1,1))
tails <- 3
heads <- 7
pi <- seq(0, 1, length = 1200)
L <- function(pi){
  pi^(tails)*(1-pi)^(heads)
}
L_integral <- integrate(L, lower = 0, upper = 1)[[1]]
plot(pi, pi^(tails)*(1-pi)^(heads)/L_integral , type = "l", 
     xlab=expression(pi), ylab = "(normalized) density", col = "grey", lwd = 3, main = "Likelihood 3 out of 10")

# posteriors
par(mfrow=c(1,1))
plot(pi, pi^(tails)*(1-pi)^(heads)/L_integral , type = "l",
     xlab=expression(pi), col = "grey", lwd = 3, ylab = "density")
points(x,dbeta(x,4,8),type="l",xlab=expression(theta),lty = 2, lwd=3,col=4)
legend(.5,3,c(expression("prior B("~alpha~"=1, "~beta~"=1)"),"likelihood","posterior"),col=c(1,"grey",4),bty="n",lty=c(1,1,2),pt.lwd=1,lwd=2,
       text.col=c(1,"grey",4))
points(x,dbeta(x,1,1),type="l",xlab=expression(theta),ylab="density",lwd=3)


plot(pi, pi^(tails)*(1-pi)^(heads)/L_integral , type = "l",
     xlab=expression(pi), col = "grey", lwd = 3, ylab = "density", ylim=c(0,3.5))
points(x,dbeta(x,6,10),type="l",xlab=expression(theta),lty = 2, lwd=3,col=4)
legend(.5,3,c(expression("prior B("~alpha~"=3, "~beta~"=3)"),"likelihood","posterior"),col=c(1,"grey",4),bty="n",lty=c(1,1,2),pt.lwd=1,lwd=2,
       text.col=c(1,"grey",4))
points(x,dbeta(x,3,3),type="l",xlab=expression(theta),ylab="density",lwd=3)

# credible interval for beta 1,1
par(mfrow=c(1,1))
plot(pi, pi^(tails)*(1-pi)^(heads)/L_integral , type = "l",
     xlab=expression(pi), col = "grey", lwd = 3, ylab = "density")
points(x,dbeta(x,4,8),type="l",xlab=expression(theta),lty = 2, lwd=3,col=4)
legend(.65,3,c(expression("prior B("~alpha~"=1, "~beta~"=1)"),"likelihood","posterior","credible interval"),col=c(1,"grey",4,3),bty="n",lty=c(1,1,2,2),pt.lwd=1,lwd=1,
       text.col=c(1,"grey",4,3))
points(x,dbeta(x,1,1),type="l",xlab=expression(theta),ylab="density",lwd=3)
L_integral <- integrate(L, lower = 0, upper = 1)[[1]]
cdf_p <- diff(pi)[1]*cumsum(L(pi))/L_integral
p_lo <- pi[which.min(abs(cdf_p - 0.025))]
p_up <- pi[which.min(abs(cdf_p - 0.975))]
## Approximate 95% central interval for pi is then:
abline(v = print(c(p_lo, p_up)), lty = 2, col = 3, lwd = 3)


